## Smart Arrays Plot Polyline


### What the package can do for you
- This package was designed for Web applications which need to plot 1D arrays in form of polylines (curves in the x, y plane).
- A plot may consist of one or several polylines (scaled relative to each other if desired), optionally with x and y axes, a coordinate grid, a text legend, selection icons, and marker text.
- Many array viewing options are provided, such as colors, fonts, zooming, scaling, shifting, rotation, layout parameters.
- Also, lists of points represented by circles or other shapes can be drawn, e.g.to draw a curve using individual points rather than connecting the points by polylines.
- The arrays to be plotted may have small or big sizes (even e.g. 1 million points). To achieve fast plotting without loosing information given typical screen or window sizes, a suitable data compression is applied before plotting (using the compression package listed at the end of the document).
- Plotting is performed using Scalable Vector Graphics SVG.


### The major API functionalities

- Class `Polyline` to construct a polyline plot of desired size from an array with optional layout and viewing parameters.

- Class `Axis` to construct an x and/or y axis for a polyline plot.

- Class `XYGrid` to construct a rectangular coordinate grid consisting of horizontal and/or vertical lines, to be used to overlay a polyline plot.

- Class `Legend` to construct a legend consisting of a text line at the top ("top title") and          optionally several more lines, each one preceded by a color rectangle (useful when displaying several polylines).

- Class `PhysUnits` to convert between "physical units" and array indices, useful for axis annotation.

- Classes `Utils` and `JsonUtils` providing useful helper functions.

- Basic usage of the package: see `example` directory.


#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Related packages

[`smart_arrays_base`: Basic functions for 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_arrays_numerics`: Numerics with 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_numerics)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size.]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_arrays_dbstore`: Store 1D and 2D arrays along with metadata on the local device.]( https://pub.dartlang.org/packages/smart_arrays_dbstore)

[`smart_arrays_peaks`: Detect peaks in 1D and 2D arrays.]( https://pub.dartlang.org/packages/smart_arrays_peaks)

[`smart_arrays_lmfit`: Fits (x, y) data given as arrays to a specified model function using the  Levenberg-Marquardt algorithm.]( https://pub.dartlang.org/packages/smart_arrays_lmfit)

[`smart_lorentz-gauss`: Compute Lorentz-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

[`smart_signal_processing`: Fourier transform and more of arrays.]( https://pub.dartlang.org/packages/smart_signal_processing)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)